import os
import shutil
import time
import datetime

import pychromecast

from player import Player
from audio_utils import Audio


class GoogleHomePlayer(Player):
    def __init__(self, name: str) -> None:
        super().__init__(name)
        google_home_mini = pychromecast.get_listed_chromecasts(friendly_names=[os.environ['GOOGLE_HOME_NAME']])[0][0]
        google_home_mini.wait()

        self._media_controller = google_home_mini.media_controller

    def _generate_audio_url(self, audio_filepath: str) -> str:
        http_ip = os.environ['HTTP_IP']
        http_port = os.environ['HTTP_PORT']
        audio_url_path = os.path.abspath(audio_filepath)[len(os.environ['AUDIO_ROOT_PATH']):].lstrip('/')
        timestamp = int(datetime.datetime.now().timestamp() * 1e6)
        return f'http://{http_ip}:{http_port}/{audio_url_path}?t={timestamp}'

    def play(self, audio_filepath: str) -> None:
        duration = Audio.from_file(audio_filepath).get_duration()
        self._media_controller.play_media(self._generate_audio_url(audio_filepath), 'audio/mpeg')
        self._media_controller.block_until_active()
        time.sleep(duration)
        #time.sleep(self._media_controller.status.duration)

    def pause(self) -> None:
        self._media_controller.pause()

    def stop(self) -> None:
        self._media_controller.stop()

    def play_message(self, message: str) -> None:
        self.interrupt = True
        super().play_message(message)
